import React from 'react';
import { createRoot } from 'react-dom/client';
import App from './App';
import './index.css';
import { Crown } from 'lucide-react';

// Loading fallback component
const LoadingFallback = () => (
  <div className="min-h-screen bg-gradient-to-b from-gray-900 to-gray-800 flex items-center justify-center p-4">
    <div className="text-center space-y-6">
      <div className="flex justify-center mb-4">
        <div className="w-16 h-16 bg-gradient-to-br from-green-500 to-blue-500 rounded-full flex items-center justify-center">
          <Crown className="text-white" size={32} />
        </div>
      </div>
      <h1 className="text-4xl font-bold text-white mb-2">StealShift</h1>
      <p className="text-gray-400">Loading your criminal empire...</p>
      <div className="flex flex-col items-center gap-2">
        <div className="w-48 h-2 bg-gray-700 rounded-full overflow-hidden">
          <div className="h-full bg-green-500 rounded-full animate-[loading_2s_ease-in-out_infinite]" />
        </div>
      </div>
    </div>
  </div>
);

// Error Boundary Component
class ErrorBoundary extends React.Component<
  { children: React.ReactNode },
  { hasError: boolean; errorMessage: string }
> {
  constructor(props: { children: React.ReactNode }) {
    super(props);
    this.state = { hasError: false, errorMessage: '' };
  }

  static getDerivedStateFromError(error: Error) {
    return { hasError: true, errorMessage: error.message };
  }

  componentDidCatch(error: Error, errorInfo: React.ErrorInfo) {
    console.error('Error caught by boundary:', error, errorInfo);
  }

  render() {
    if (this.state.hasError) {
      return (
        <div className="min-h-screen bg-gradient-to-b from-gray-900 to-gray-800 flex items-center justify-center p-4">
          <div className="text-center space-y-6">
            <div className="flex justify-center mb-4">
              <div className="w-16 h-16 bg-gradient-to-br from-red-500 to-orange-500 rounded-full flex items-center justify-center">
                <Crown className="text-white" size={32} />
              </div>
            </div>
            <h1 className="text-4xl font-bold text-white mb-2">Oops!</h1>
            <p className="text-gray-400">Something went wrong loading the game.</p>
            <div className="bg-gray-800 p-4 rounded-lg text-left text-sm text-red-400 mb-4 max-w-md mx-auto">
              <code>{this.state.errorMessage}</code>
            </div>
            <button
              onClick={() => window.location.reload()}
              className="bg-red-600 hover:bg-red-700 px-6 py-3 rounded-lg text-white font-medium"
            >
              Reload Page
            </button>
          </div>
        </div>
      );
    }

    return this.props.children;
  }
}

const container = document.getElementById('root');
if (!container) {
  throw new Error('Root element not found');
}

const root = createRoot(container);

// Detect StackBlitz environment
const isStackBlitz = typeof window !== 'undefined' && (
  window.location.hostname.includes('stackblitz') ||
  window.location.hostname.includes('.webcontainer.io') ||
  navigator.userAgent.includes('StackBlitz')
);

// Only register service worker in production and not in StackBlitz
if (!isStackBlitz && 'serviceWorker' in navigator && import.meta.env.PROD) {
  window.addEventListener('load', () => {
    navigator.serviceWorker
      .register('/sw.js', { 
        scope: '/',
        updateViaCache: 'none'
      })
      .then((registration) => {
        // Check for updates immediately
        registration.update();
        
        // Clear cache
        if (registration.active) {
          registration.active.postMessage('CLEAR_CACHE');
        }
        
        // Set up periodic updates
        setInterval(() => {
          registration.update();
        }, 60 * 60 * 1000); // Check for updates every hour
      })
      .catch((error) => {
        console.error('Service worker registration failed:', error);
      });
  });
}

// Render with error boundary
root.render(
  <React.StrictMode>
    <React.Suspense fallback={<LoadingFallback />}>
      <ErrorBoundary>
        <App />
      </ErrorBoundary>
    </React.Suspense>
  </React.StrictMode>
);